==> eav_field-2.0.0.tar.gz: eav_field/src/Plugin/Field/FieldType/EavItem.php <==
<?php

namespace Drupal\eav_field\Plugin\Field\FieldType;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Field\Annotation\FieldType;
use Drupal\Core\Field\Plugin\Field\FieldType\EntityReferenceItem;
use Drupal\Core\Form\FormStateInterface;
use Drupal\eav_field\Entity\EavValue;

/**
 * @FieldType(
 *   id = "eav",
 *   label = @Translation("EAV attributes"),
 *   category = @Translation("Reference"),
 *   description = @Translation("A field containing many entity attributes and their values"),
 *   cardinality = \Drupal\Core\Field\FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED,
 *   default_widget = "eav_widget",
 *   default_formatter = "eav_formatter",
 *   list_class = "\Drupal\eav_field\Plugin\Field\FieldType\EavItemList",
 * )
 */
class EavItem extends EntityReferenceItem {

  /**
   * {@inheritdoc}
   */
  public static function defaultStorageSettings() {
    return [
      'target_type' => 'eav_value',
    ] + parent::defaultStorageSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function storageSettingsForm(array &$form, FormStateInterface $form_state, $has_data) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    return [];
  }

  /**
   * {@inheritdoc}
   * @TODO Remove?
   */
  public function preSave() {
    if ($eav_value = $this->getValueEntity()) {
      $eav_value->save();

      if ($this->target_id === NULL) {
        $this->target_id = $eav_value->id();
      }
    }
  }

  /**
   * Return eav value entity.
   *
   * @return EavValue
   */
  public function getValueEntity() {
    return $this->entity;
  }

  /**
   * Format value field in selected formatter.
   */
  public function viewValueField() {
    return $this->getValueEntity()->viewValueField();
  }

  /**
   * {@inheritdoc}
   */
  public static function getPreconfiguredOptions() {
    return [];
  }

}

==> eav_field-2.0.1.tar.gz: eav_field/src/Plugin/Field/FieldType/EavItem.php <==
<?php

namespace Drupal\eav_field\Plugin\Field\FieldType;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Field\Annotation\FieldType;
use Drupal\Core\Field\Plugin\Field\FieldType\EntityReferenceItem;
use Drupal\Core\Form\FormStateInterface;
use Drupal\eav_field\Entity\EavValue;

/**
 * @FieldType(
 *   id = "eav",
 *   label = @Translation("EAV attributes"),
 *   category = @Translation("Reference"),
 *   description = @Translation("A field containing many entity attributes and their values"),
 *   cardinality = \Drupal\Core\Field\FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED,
 *   default_widget = "eav_widget",
 *   default_formatter = "eav_formatter",
 *   list_class = "\Drupal\eav_field\Plugin\Field\FieldType\EavItemList",
 * )
 */
class EavItem extends EntityReferenceItem {

  /**
   * {@inheritdoc}
   */
  public static function defaultStorageSettings() {
    return [
      'target_type' => 'eav_value',
    ] + parent::defaultStorageSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function storageSettingsForm(array &$form, FormStateInterface $form_state, $has_data) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    return [];
  }

  /**
   * {@inheritdoc}
   * @TODO Remove?
   */
  public function preSave() {
    if ($eav_value = $this->getValueEntity()) {
      $eav_value->save();

      if ($this->target_id === NULL) {
        $this->target_id = $eav_value->id();
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getPreconfiguredOptions() {
    return [];
  }

  /**
   * Return eav_value entity.
   */
  public function getValueEntity(): ?EavValue {
    return $this->entity;
  }

  /**
   * Format value field in selected formatter.
   */
  public function viewValueField() {
    return $this->getValueEntity()->viewValueField();
  }

}
